#' 99329 Coliphage, somatic, E. coli C-host, 2-stepenrichment presence/absence per 1 liter
#'
#' A table containing the USGS Coliphage, somatic, E. coli C-host,
#' 2-stepenrichment presence/absence per 1 liter parameter codes.
#'
#' @format A data frame with 2 rows and 3 variables:
#' \describe{
#' \item{Parameter Code}{USGS Parameter Code}
#' \item{Fixed Value}{Fixed Value}
#' \item{Fixed Text}{Fixed Text}
#' }
#'
#'
#' @references
#' This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See \url{https://help.waterdata.usgs.gov/codes-and-parameters/}.
#'
#'
#'
#'
"pmcode_99329"
#> [1] "pmcode_99329"
